@@ -26,7 +26,7 @@ NULL
 
 ## A fix to let CRAN check NOTEs diasappear for non-standard-evaluation used
 ## cf. http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
-globalVariables(c("one_of", ".", "matches", # dplyr
+globalVariables(c("one_of", ".", "matches", "starts_with", # dplyr
                   "manifesto_id", "country", "party", "edate", # general dataset
                   "md5sum_text.x", "md5sum_text.y", # & metadata
                   "download", "url_original", "is_primary_doc",
